@@ -22,6 +22,9 @@
 #include "gd-two-lines-renderer.h"
 #include <string.h>
 
+#define SUBTITLE_DIM_PERCENTAGE 0.55
+#define SUBTITLE_SIZE_PERCENTAGE 0.82
+
 G_DEFINE_TYPE (GdTwoLinesRenderer, gd_two_lines_renderer, GTK_TYPE_CELL_RENDERER_TEXT)
 
 struct _GdTwoLinesRendererPrivate {
@@ -78,6 +81,40 @@ create_layout_with_attrs (GtkWidget *widget,
   return layout;
 }
 
+static void
+apply_subtitle_style_to_layout (GtkStyleContext *context,
+                                PangoLayout     *layout,
+                                GtkStateFlags    flags)
+{
+  PangoFontDescription *desc;
+  GdkRGBA rgba;
+  PangoAttrList *layout_attr;
+  PangoAttribute *attr_color;
+
+  gtk_style_context_get (context, flags,
+                         "font", &desc,
+                         "color", &rgba,
+                         NULL);
+
+  /* Set the font size */
+  pango_font_description_set_size (desc, pango_font_description_get_size (desc) * SUBTITLE_SIZE_PERCENTAGE);
+  pango_layout_set_font_description (layout, desc);
+  pango_font_description_free (desc);
+
+  /* Set the color */
+  rgba.red = CLAMP(1.0 - ((1.0 - rgba.red) * SUBTITLE_DIM_PERCENTAGE), 0.0, 1.0);
+  rgba.green = CLAMP(1.0 - ((1.0 - rgba.green) * SUBTITLE_DIM_PERCENTAGE), 0.0, 1.0);
+  rgba.blue = CLAMP(1.0 - ((1.0 - rgba.blue) * SUBTITLE_DIM_PERCENTAGE), 0.0, 1.0);
+
+  layout_attr = pango_attr_list_new ();
+  attr_color = pango_attr_foreground_new (rgba.red * 65535,
+                                          rgba.green * 65535,
+                                          rgba.blue * 65535);
+  pango_attr_list_insert (layout_attr, attr_color);
+  pango_layout_set_attributes (layout, layout_attr);
+  pango_attr_list_unref (layout_attr);
+}
+
 static void
 gd_two_lines_renderer_prepare_layouts (GdTwoLinesRenderer *self,
                                        const GdkRectangle *cell_area,
@@ -106,9 +143,16 @@ gd_two_lines_renderer_prepare_layouts (GdTwoLinesRenderer *self,
     }
   else
     {
+      GtkStyleContext *context;
+
       line_two = create_layout_with_attrs (widget, cell_area,
                                            self, PANGO_ELLIPSIZE_END);
 
+      context = gtk_widget_get_style_context (widget);
+      gtk_style_context_save (context);
+      apply_subtitle_style_to_layout (context, line_two, GTK_STATE_FLAG_NORMAL);
+      gtk_style_context_restore (context);
+
       pango_layout_set_height (line_one, - (self->priv->text_lines - 1));
       pango_layout_set_height (line_two, -1);
       pango_layout_set_text (line_two, self->priv->line_two, -1);
@@ -278,7 +322,8 @@ gd_two_lines_renderer_render (GtkCellRenderer      *cell,
                                    NULL, &line_one_height);
 
       gtk_style_context_save (context);
-      gtk_style_context_add_class (context, "dim-label");
+
+      apply_subtitle_style_to_layout (context, layout_two, flags);
 
       state = gtk_cell_renderer_get_state (cell, widget, flags);
       gtk_style_context_set_state (context, state);
@@ -309,7 +354,7 @@ gd_two_lines_renderer_get_preferred_width (GtkCellRenderer *cell,
 {
   PangoContext *context;
   PangoFontMetrics *metrics;
-  const PangoFontDescription *font_desc;
+  PangoFontDescription *font_desc;
   GtkStyleContext *style_context;
   gint nat_width, min_width;
   gint xpad, char_width, wrap_width, text_width;
@@ -331,13 +376,14 @@ gd_two_lines_renderer_get_preferred_width (GtkCellRenderer *cell,
 
   /* Fetch the average size of a charachter */
   context = gtk_widget_get_pango_context (widget);
-  font_desc = gtk_style_context_get_font (style_context, 0);
+  gtk_style_context_get (style_context, 0, "font", &font_desc, NULL);
   metrics = pango_context_get_metrics (context, font_desc,
                                        pango_context_get_language (context));
 
   char_width = pango_font_metrics_get_approximate_char_width (metrics);
 
   pango_font_metrics_unref (metrics);
+  pango_font_description_free (font_desc);
 
   /* enforce minimum width for ellipsized labels at ~3 chars */
   ellipsize_chars = 3;
