@@ -363,7 +363,7 @@ show_codec_confirmation_dialog (TotemCodecInstallContext *ctx,
 	/* TRANSLATORS: this is a button to launch a codec installer.
 	 * %s will be replaced with the software installer's name, e.g.
 	 * 'Software' in case of gnome-software. */
-	button_text = g_strdup_printf ("_Find in %s", install_helper_display_name);
+	button_text = g_strdup_printf (_("_Find in %s"), install_helper_display_name);
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", message_text);
 	button = gtk_dialog_add_button (GTK_DIALOG (dialog),
 	                                button_text,
