@@ -30,7 +30,7 @@
 #define GNOME_DESKTOP_USE_UNSTABLE_API 1
 #include <libgnome-desktop/gnome-desktop-thumbnail.h>
 
-#define DEFAULT_MAX_THREADS   5
+#define DEFAULT_MAX_THREADS   1
 #define THUMB_SEARCH_SIZE     256
 #define THUMB_SEARCH_HEIGHT   THUMB_SEARCH_SIZE
 #define SOURCES_MAX_HEIGHT    64
@@ -189,7 +189,7 @@ thumbnail_media_async_thread (GTask    *task,
 			      gpointer  user_data)
 {
 	GrlMedia *media;
-	GdkPixbuf *pixbuf;
+	GdkPixbuf *pixbuf, *tmp_pixbuf;
 	const char *uri;
 	GDateTime *mtime;
 
@@ -217,19 +217,23 @@ thumbnail_media_async_thread (GTask    *task,
 		return;
 	}
 
-	pixbuf = gnome_desktop_thumbnail_factory_generate_thumbnail (factory, uri, "video/x-totem-stream");
+	tmp_pixbuf = gnome_desktop_thumbnail_factory_generate_thumbnail (factory, uri, "video/x-totem-stream");
 
-	if (!pixbuf) {
+	if (!tmp_pixbuf) {
 		g_task_return_new_error (task, G_IO_ERROR, G_IO_ERROR_FAILED, "Thumbnailing failed");
 		g_object_unref (task);
 		return;
 	}
 
-	gnome_desktop_thumbnail_factory_save_thumbnail (factory, pixbuf, uri, g_date_time_to_unix (mtime));
+	gnome_desktop_thumbnail_factory_save_thumbnail (factory, tmp_pixbuf, uri, g_date_time_to_unix (mtime));
 
 	/* Save the thumbnail URL for the bookmarks source */
 	save_bookmark_thumbnail (media, uri);
 
+	/* Add frame */
+	pixbuf = load_icon (tmp_pixbuf, FALSE, FILL_MOVIE);
+	g_object_unref (tmp_pixbuf);
+
 	g_task_return_pointer (task, pixbuf, g_object_unref);
 	g_object_unref (task);
 }
@@ -331,7 +335,7 @@ totem_grilo_get_thumbnail (GObject             *object,
 
 	file = g_file_new_for_uri (url_thumb);
 	g_task_set_task_data (task, file, g_object_unref);
-	g_file_read_async (file, G_PRIORITY_DEFAULT, NULL,
+	g_file_read_async (file, G_PRIORITY_DEFAULT, cancellable,
 			   get_stream_thumbnail_cb, task);
 }
 
